"""
This module implements a set of utilities for extracting features and
train/testing :class:`revscoring.Model` from the command-line.  When the
revscoring python package is installed, a `revscoring` utility should be
available from the commandline.  Run `revscoring -h` for more
information:

cv_train
++++++++
.. automodule:: revscoring.utilities.cv_train

extract
+++++++
.. automodule:: revscoring.utilities.extract

fetch_text
++++++++++
.. automodule:: revscoring.utilities.fetch_text

fit
+++
.. automodule:: revscoring.utilities.fit

model_info
++++++++++
.. automodule:: revscoring.utilities.model_info

score
+++++
.. automodule:: revscoring.utilities.score

test_model
++++++++++
.. automodule:: revscoring.utilities.test_model

tune
++++
.. automodule:: revscoring.utilities.tune
"""
